slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVMultInPlaceHermitianTranspose

Update a set of vectors as V(:,s:e-1) = V*Q'(:,s:e-1).

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVMultInPlaceHermitianTranspose(BV V,Mat Q,PetscInt s,PetscInt e)

Logically Collective on V

### Input Parameters

| Q | - a sequential dense matrix
| s | - first column of V to be overwritten
| e | - first column of V not to be overwritten

### Input/Output Parameter

| V | - basis vectors

### Notes

This is a variant of BVMultInPlace() where the conjugate transpose of Q is used.

### See Also

BVMultInPlace()

### Level

intermediate

### Location

src/sys/classes/bv/interface/bvops.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages